GroqToolCall class

Available extensions

Constructors

GroqToolCall({required String callId, required String functionName, required Map<String, dynamic> arguments})

Properties

arguments → Map<String, dynamic>
final
callId → String
final
functionName → String
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>

Available on GroqToolCall, provided by the GroqToolCallExtension extension

toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override